Welcome to django-paypal's documentation!
=========================================

Django PayPal is a pluggable application that implements with PayPal Payments
Standard and Payments Pro.

.. note::

   These docs are for django-paypal |release| - please ensure that corresponds
   to the version you are using!

Contents:

.. toctree::
   :maxdepth: 2

   install
   overview
   standard/index
   pro/index
   tests
   release_notes
   updatedb
   settings


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
